# Tark
Tark is a simple markdown parser.

Supported syntax:

code blocks
\`\`\`lang
code here
\`\`\`

inline code
\`code\`

links
\[link text\]\(url\)

images
\!\[alt text\]\(url\)

titles
\#\# title

inline html
\<p\\\>html here\<\/p\>